<?php

/**
 * @file
 * Calls results to administration's pages for the Only One module.
 */

/**
 * Form constructor for module configuration.
 */
function onlyone_admin_settings($form_state) {
  $available_content_types = _onlyone_available_content_types(TRUE);
  $not_available_content_types = _onlyone_not_available_content_types(TRUE);
  $form = array();

  if (count($available_content_types)) {
    // The fieldset of available content types.
    $form['available_content_type'] = array(
      '#type' => 'fieldset',
      '#title' => t('Available content types to have Only One node'),
      '#collapsible' => TRUE,
      '#collapsed' => FALSE,
    );
    // All the available content types.
    $form['available_content_type']['onlyone_node_types'] = array(
      '#type' => 'checkboxes',
      '#title' => t('Configure these content types to allow for the creation of Only One node per language'),
      '#options' => $available_content_types,
      '#default_value' => variable_get('onlyone_node_types', array()),
      '#description' => t('The selected content types will allow Only One node per language.'),
    );
  }
  // If all the content types are available we don't need to show the fieldset.
  if (count($not_available_content_types)) {
    $collapsed = count($available_content_types) ? TRUE : FALSE;
    // The fieldset of not available content types.
    $form['not_available_content_type'] = array(
      '#type' => 'fieldset',
      '#title' => t('Not available content types to have Only One node'),
      '#description' => t('The following content types have more than one node in at least one language:'),
      '#collapsible' => $collapsed,
      '#collapsed' => $collapsed,
    );
    // Showing all the not availables content types.
    foreach ($not_available_content_types as $key => $value) {
      $form['not_available_content_type'][$key] = array(
        '#type' => 'item',
        '#markup' => $value,
      );
    }
  }

  // Set a submit handler manually because the default submit handler
  // gets overridden by the system_settings_form() submit handler.
  $form['#submit'][] = 'onlyone_custom_form_submit';

  // Show the submit button if there is availables content types.
  if (count($available_content_types)) {
    return system_settings_form($form);
  }
  else {
    $form = system_settings_form($form);
    unset($form['actions']);
    return $form;
  }
}

/**
 * Submit handler for the custom form.
 */
function onlyone_custom_form_submit($form, &$form_state) {
  // Cleaning the array.
  foreach ($form_state['values']['onlyone_node_types'] as $content_type => $value) {
    if ($value !== 0) {
      $form_state['values']['onlyone_node_types'][] = $content_type;
    }
    unset($form_state['values']['onlyone_node_types'][$content_type]);
  }
}
